@@ -40,10 +40,10 @@ def on_connect(client, userdata, flags, rrc):
 
 
 # 一旦订阅到消息，回调此方法
-def on_message(_, obj, msg):
+def on_message(client, obj, msg):
     global callback_dit
     topic = msg.topic
-    callback_dit[topic](msg.payload)
+    callback_dit[topic](json.loads(str(msg.payload, encoding="utf-8")), str(client._client_id, encoding='utf-8'))
 
 
 def callback():
@@ -84,10 +84,14 @@ class Dxr_Subscriber:
     def __init__(self, topic, callback):
         global callback_dit, topic_list_str_pub, topic_list_str_sub
         self.mqttc = Mqtt()
-        self.mqttc.subscribe(topic)
-        self.topic = topic
+        if isinstance(topic, str):
+            self.mqttc.subscribe(topic)
+            self.topic = topic
+        else:
+            self.mqttc.subscribe(topic.topic)
+            self.topic = topic.topic
         self.callback = callback
-        callback_dit[topic] = callback
+        callback_dit[self.topic] = callback
         topic_list_str_sub = client_id + '_sub:\n'
         for item in callback_dit.keys():
             topic_list_str_sub = '' + topic_list_str_sub + item + '\n'
@@ -97,18 +101,26 @@ class Dxr_Subscriber:
 class Dxr_Publisher:
     def __init__(self, topic):
         global publish_dit, topic_list_str_pub, topic_list_str_sub
-        self.topic = topic
+        if isinstance(topic, str):
+            self.topic = topic
+            self.data_type = None
+        else:
+            self.topic = topic.topic
+            self.data_type = topic
         # 新建mqtt客户端，默认没有clientid，clean_session=True, transport="tcp"
         self.mqttc = Mqtt()
-        if topic not in publish_dit:
-            publish_dit.append(topic)
+        if self.topic not in publish_dit:
+            publish_dit.append(self.topic)
         topic_list_str_pub = client_id + '_pub:\n'
         for item in publish_dit:
             topic_list_str_pub = '' + topic_list_str_pub + item + '\n'
         self.mqttc.publish('/topic/' + client_id, retain=True, payload=topic_list_str_pub + topic_list_str_sub)
 
     def publish(self, msg):
-        self.mqttc.publish(self.topic, json.dumps(msg), qos=0)
+        if self.data_type:
+            self.mqttc.publish(self.topic, str(msg), qos=0)
+        else:
+            self.mqttc.publish(self.topic, json.dumps(msg), qos=0)
 
 
 class Dxr_UnSubscriber:
